# TypeDAL

Typing support for [PyDAL](http://web2py.com/books/default/chapter/29/6)

More documentation following soon, compare example_old.py (pydal) with example_new.py (typedal) to get an idea of how it
works.